@@ -205,7 +205,7 @@ LVM_FLAGS = ("--noheadings", "--units", "b", "--nosuffix", "--separator",
 
 PV_PREFIX = "/dev/mapper"
 # Assuming there are no spaces in the PV name
-re_pvName = re.compile(PV_PREFIX + '[^\s\"]+', re.MULTILINE)
+re_pvName = re.compile(PV_PREFIX + r'[^\s\"]+', re.MULTILINE)
 
 PVS_CMD = ("pvs",) + LVM_FLAGS + ("-o", PV_FIELDS)
 VGS_CMD = ("vgs",) + LVM_FLAGS + ("-o", VG_FIELDS)
@@ -320,9 +320,9 @@ class LVMRunner(object):
     SUPPRESS_WARNINGS = re.compile(
         "|".join([
             "WARNING: This metadata update is NOT backed up",
-            ("WARNING: ignoring metadata seqno \d+ on /dev/mapper/\w+ for "
-             "seqno \d+ on /dev/mapper/\w+ for VG \w+"),
-            "WARNING: Inconsistent metadata found for VG \w+"
+            (r"WARNING: ignoring metadata seqno \d+ on /dev/mapper/\w+ for "
+             r"seqno \d+ on /dev/mapper/\w+ for VG \w+"),
+            r"WARNING: Inconsistent metadata found for VG \w+"
         ]),
         re.IGNORECASE)
 
@@ -1568,6 +1568,11 @@ def createLV(vgName, lvName, size, activate=True, contiguous=False,
     cmd = ["lvcreate"]
     cmd.extend(LVM_NOBACKUP)
     cmd.extend(("--contiguous", cont, "--size", "%sm" % size))
+    # Disable wiping signatures, enabled by default in RHEL 8.4. We own the VG
+    # and the LVs and we know it is alwasy safe to zero a new LV. With this
+    # option, LVM will zero the first 4k of the device without confirmation.
+    # See https://bugzilla.redhat.com/1946199.
+    cmd.extend(("--wipesignatures", "n"))
     for tag in initialTags:
         cmd.extend(("--addtag", tag))
     cmd.extend(("--name", lvName, vgName))
